<?php

/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package abstract_grid
 */
if (!function_exists('abstract_posted_on')) :

    /**
     * Prints HTML with meta information for the current post-date/time and author.
     */
    function abstract_posted_on() {
        $time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
        if (get_the_time('U') !== get_the_modified_time('U')) {
            $time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
        }

        $time_string = sprintf($time_string, esc_attr(get_the_date('c')), esc_html(get_the_date()), esc_attr(get_the_modified_date('c')), esc_html(get_the_modified_date())
        );

        $posted_on = sprintf(
                esc_html_x('On %s', 'post date', 'abstract-grid'), '<li class="date"><a href="' . esc_url(get_permalink()) . '" rel="bookmark">' . $time_string . '</a></li>'
        );

        $categories_list = get_the_category_list(esc_html__(' , ', 'abstract-grid'));


        $byline = sprintf(
                esc_html_x('by %s', 'post author', 'abstract-grid'), '<span class="author vcard"><a class="url fn n" href="' . esc_url(get_author_posts_url(get_the_author_meta('ID'))) . '">' . esc_html(get_the_author()) . '</a></span>'
        );

        echo '<span class="posted-on">' . $posted_on . '</span><span class="byline"> ' . $categories_list . '</span>'; // WPCS: XSS OK.
    }

endif;

if (!function_exists('abstract_entry_footer')) :

    /**
     * Prints HTML with meta information for the categories, tags and comments.
     */
    function abstract_entry_footer() {
        // Hide category and tag text for pages.
        if ('post' === get_post_type()) {
            /* translators: used between list items, there is a space after the comma */
            $categories_list = get_the_category_list(esc_html__(', ', 'abstract-grid'));
            /*
              if ( $categories_list && abstract_categorized_blog() ) {
              printf( '<span class="cat-links">' . esc_html__( 'Posted in %1$s', 'abstract-grid') . '</span>', $categories_list ); // WPCS: XSS OK.
              }
             */
            /* translators: used between list items, there is a space after the comma */
            $tags_list = get_the_tag_list('', esc_html__(' ', 'abstract-grid'));
            if ($tags_list) {
                printf('<p class="tags">' . esc_html__('Tagged in :  %1$s', 'abstract-grid') . '</p>', $tags_list); // WPCS: XSS OK.
            }
        }

        if (!is_single() && !post_password_required() && ( comments_open() || get_comments_number() )) {
            echo '<span class="comments-link">';
            /* translators: %s: post title */
            comments_popup_link(sprintf(wp_kses(__('Leave a Comment<span class="screen-reader-text"> on %s</span>', 'abstract-grid'), array('span' => array('class' => array()))), get_the_title()));
            echo '</span>';
        }

        edit_post_link(
                sprintf(
                        /* translators: %s: Name of current post */
                        esc_html__('Edit %s', 'abstract-grid'), the_title('<span class="screen-reader-text">"', '"</span>', false)
                ), '<span class="edit-link">', '</span>'
        );
    }

endif;

/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
function abstract_categorized_blog() {
    if (false === ( $all_the_cool_cats = get_transient('abstract_categories') )) {
        // Create an array of all the categories that are attached to posts.
        $all_the_cool_cats = get_categories(array(
            'fields' => 'ids',
            'hide_empty' => 1,
            // We only need to know if there is more than one category.
            'number' => 2,
                ));

        // Count the number of categories that are attached to the posts.
        $all_the_cool_cats = count($all_the_cool_cats);

        set_transient('abstract_categories', $all_the_cool_cats);
    }

    if ($all_the_cool_cats > 1) {
        // This blog has more than 1 category so abstract_categorized_blog should return true.
        return true;
    } else {
        // This blog has only 1 category so abstract_categorized_blog should return false.
        return false;
    }
}

/**
 * Flush out the transients used in abstract_categorized_blog.
 */
function abstract_category_transient_flusher() {
    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
        return;
    }
    // Like, beat it. Dig?
    delete_transient('abstract_categories');
}

add_action('edit_category', 'abstract_category_transient_flusher');
add_action('save_post', 'abstract_category_transient_flusher');













if (!function_exists('abstract_entry_meta')) :

    /**
     * Prints HTML with meta information for the categories, tags and comments.
     */
    function abstract_entry_meta() {
        // Hide category and tag text for pages.
        if ('post' === get_post_type()) {
            /* translators: used between list items, there is a space after the comma */
            $categories_list = get_the_category_list(esc_html__(' ', 'abstract-grid'));
            if ($categories_list && abstract_categorized_blog()) {
                printf('<span class="cat-links">' . esc_html__('Category %1$s', 'abstract-grid') . '</span>', $categories_list); // WPCS: XSS OK.
            }

            /* translators: used between list items, there is a space after the comma */
            $tags_list = get_the_tag_list('', esc_html__(', ', 'abstract-grid'));
            if ($tags_list) {
                printf('<span class="tags-links">' . esc_html__('Tagged %1$s', 'abstract-grid') . '</span>', $tags_list); // WPCS: XSS OK.
            }
        }

        edit_post_link(
                sprintf(
                        /* translators: %s: Name of current post */
                        esc_html__('Edit %s', 'abstract-grid'), the_title('<span class="screen-reader-text">"', '"</span>', false)
                ), '<span class="edit-link">', '</span>'
        );
    }

endif;



if (!function_exists('abstract_author')) :

    function abstract_author() {

        if ('post' === get_post_type()) {
            global $post;
            $user_image = get_the_author_meta('_abs_user_img', $post->post_author);
            $user_des = get_the_author_meta('description', $post->post_author);
            $user_name = get_the_author_meta('display_name', $post->post_author);
            $user_archive = get_author_posts_url($post->post_author);

            $facebook = get_the_author_meta('_abs_facebook', $post->post_author);
            $twitter = get_the_author_meta('_abs_twitter', $post->post_author);
            $instgram = get_the_author_meta('_abs_instagram', $post->post_author);
            $google = get_the_author_meta('_abs_google', $post->post_author);

            if($user_image) { echo "<img src='$user_image' alt='author'>"; } 
            
            echo "
            <div class='about'>
                <h4><a href='{$user_archive}'>{$user_name}</a></h4>

                <p>
                {$user_des}
                </p>
                
                <ul class='author-social'>
                ";
            if ($facebook)
                "<li><a href='{$facebook}'>Facebook</a></li>";
            if ($twitter)
                "<li><a href='{$twitter}'>Twitter</a></li>";
            if ($google)
               "<li><a href='{$google}'>GooglePlus</a></li>";
            if ($instgram)
               "<li><a href='{$instgram}'>Instagram</i></a></li>";

            echo "
                </ul>
            </div>
            ";
        }
    }


    
    
    
endif;